--[[
******************************************************************
Script to install the magnetic stripe fonts on the system.

 ***** IMPORTANT NOTE *****
The script to uninstall fonts does not need to be called first. 
If the font is detected on the system it will be unregistered before
the new font file is copied and registered on the system.
******************************************************************
]]--

fDebug("\r\n\Entering Install Magstripe Font script.");
-- Reset the return status string so it contains only text from this script when it returns
strScriptReturnStatus = "";
local bContinue = true;

local tblFileNames = { "DXP01_T1.ttf", "DXP01_T2.ttf","DXP01_T3.ttf","DXP01_JIS.ttf" };
local tblFontNames = { "Mag Track 1 XPS Card Printer", "Mag Track 2 XPS Card Printer", "Mag Track 3 XPS Card Printer", "Mag Track JIS XPS Card Printer"}

-- ************************************
--   Get Fonts folder path
-- ************************************
local fonts_dir = Shell.GetFolder(SHF_FONTS); -- Gets the path to the user's Font directory.
local error = Application.GetLastError();
if (error ~= 0) then
	strScriptReturnStatus = String.Concat(strScriptReturnStatus, "\r\n Error detecting system font folder: "..error); -- log the error that caused the failure.
	fDebug("Error detecting system font folder: "..error);
	bContinue = false;
else
	strScriptReturnStatus = String.Concat(strScriptReturnStatus, "\r\n Font directory: "..fonts_dir);
	fDebug("Font directory: "..fonts_dir);
end

if (bContinue) then
	-- Put a loop here to loop through a table of font names and file names so the same code can be reused n times.
	local fontCount = Table.Count(tblFontNames);
	fDebug("Nmbr of fonts to install: "..fontCount);
	local loopCounter = 1;
	
	repeat  
		local strFontFileName = tblFileNames[loopCounter];
		local strFontName = tblFontNames[loopCounter];
		--  ************************************
		--  Detect if the font is installed.  If it is, try to unregister it.
		--  This may fail because the file is present but the font is not registered.
		--  If it fails, continue on.
		--  ************************************
		if (File.DoesExist(fonts_dir.."\\"..strFontFileName)) then -- Check if the font exits.  If it does, unregister it.
			strScriptReturnStatus = String.Concat(strScriptReturnStatus, "\r\n Magstripe font detected: "..strFontFileName);
			fDebug("Magstripe font detected: "..strFontFileName);
			System.UnregisterFont(fonts_dir.."\\"..strFontFileName, strFontName, true);
			error = Application.GetLastError();
			if (error ~= 0) then
			 strScriptReturnStatus = String.Concat(strScriptReturnStatus, "\r\n Error removing font: "..error); -- log the error that caused the failure.
			 fDebug("Error unregistering font: "..error);
			else
			 strScriptReturnStatus = String.Concat(strScriptReturnStatus, "\r\n Font uninstalled.");
			 fDebug("Font unregistered.");
			end
		end
		
		-- ************************************
		-- Copy the font file to the Fonts directory overwriting the file if it is already there.
		-- This may fail if the font is marked 'in use'
		-- If it fails, continue on.
		-- 	************************************
		strScriptReturnStatus = String.Concat(strScriptReturnStatus, "\r\n Copying font file: "..strFontFileName);
		fDebug("Copying magstripe font file: "..strFontFileName);
		File.Copy(_SourceFolder.."\\AutoPlay\\Fonts\\"..strFontFileName, fonts_dir.."\\"..strFontFileName, false, true, false, true, nil); -- Copy the magstripe file to the Fonts folder.
		error = Application.GetLastError();
		if (error ~= 0) then
			strScriptReturnStatus = String.Concat(strScriptReturnStatus, "\r\n Error copying font file. Error: "..error); -- log the error that caused the failure.
			fDebug("Error copying font file. Error: "..error);
		else
			strScriptReturnStatus = String.Concat(strScriptReturnStatus, "\r\n Font copied.");
			fDebug("Font file copied.");
		end
		
		-- ************************************
		-- Register the font.
		-- This should not fail.
		-- ************************************
		if (File.DoesExist(fonts_dir.."\\"..strFontFileName)) then
			strScriptReturnStatus = String.Concat(strScriptReturnStatus, "\r\n Registering magstripe font: "..strFontFileName);
			fDebug("Registering magstripe font file: "..strFontFileName.." with name: "..strFontName);
			System.RegisterFont(fonts_dir.."\\"..strFontFileName, strFontName, true); -- Register the font.
			error = Application.GetLastError();
			if (error ~= 0) then
				strScriptReturnStatus = String.Concat(strScriptReturnStatus, "\r\n Error installing font: "..error); -- log the error that caused the failure.
				fDebug("Error registering font file. Error: "..error);
			else
				strScriptReturnStatus = String.Concat(strScriptReturnStatus, "\r\n Font installed. ");
				fDebug("Font file registered.");
			end
		end
	end
	
	loopCounter = loopCounter + 1;
until loopCounter > fontCount

-- Dialog.Message("DEBUG", strScriptReturnStatus, MB_OK, MB_ICONNONE, MB_DEFBUTTON1);

-- Send a signal back to the main script using the bContinueInstall flag.
-- always continue. Don't abort the driver installation because of a font issue.
bContinueInstall = true;
fDebug("Exiting Install Magstripe Font script.\r\n ");
